@@ -14,7 +14,7 @@ from joblib import Parallel, delayed
 
 try:  # for mne < 1.0
     from mne.externals.h5io import read_hdf5, write_hdf5
-except ImportError:
+except (ImportError, ModuleNotFoundError):
     from h5io import read_hdf5, write_hdf5
 
 import mne
@@ -52,7 +52,7 @@ def validation_curve(epochs, y=None, param_name="thresh", param_range=None,
 
     Parameters
     ----------
-    epochs : instance of mne.Epochs.
+    epochs : instance of mne.Epochs
         The epochs.
     y : array | None
         The labels.
@@ -63,8 +63,9 @@ def validation_curve(epochs, y=None, param_name="thresh", param_range=None,
         The values of the parameter that will be evaluated.
         If None, 15 values between the min and the max threshold
         will be tested.
-    cv : int, cross-validation generator or an iterable, optional
+    cv : int | sklearn.model_selection object | iterable | None
         Determines the cross-validation strategy.
+        Defaults to None.
     return_param_range : bool
         If True the used param_range is returned.
         Defaults to False.
@@ -129,6 +130,25 @@ def read_auto_reject(fname):
     return ar
 
 
+def read_reject_log(fname):
+    """Read a reject log.
+
+    Parameters
+    ----------
+    fname : str
+        The filename where the reject log is saved.
+
+    Returns
+    -------
+    reject_log : instance of autoreject.RejectLog
+    """
+    reject_log_data = np.load(fname)
+    reject_log = RejectLog(bad_epochs=reject_log_data['bad_epochs'],
+                           labels=reject_log_data['labels'],
+                           ch_names=reject_log_data['ch_names'])
+    return reject_log
+
+
 class BaseAutoReject(BaseEstimator):
     """Base class for rejection."""
 
@@ -180,19 +200,21 @@ def get_rejection_threshold(epochs, decim=1, random_state=None,
 
     Parameters
     ----------
-    epochs : mne.Epochs object
+    epochs : mne.Epochs
         The epochs from which to estimate the epochs dictionary
     decim : int
         The decimation factor: Increment for selecting every nth time slice.
-    random_state : int seed, RandomState instance, or None (default)
+    random_state : int | np.random.RandomState | None
         The seed of the pseudo random number generator to use.
+        Defaults to None.
     ch_types : str | list of str | None
         The channel types for which to find the rejection dictionary.
         e.g., ['mag', 'grad']. If None, the rejection dictionary
-        will have keys ['mag', 'grad', 'eeg', 'eog', 'hbo', 'hbr'].
-    cv : a scikit-learn cross-validation object
-        Defaults to cv=5
-    verbose : boolean
+        will have keys ['mag', 'grad', 'eeg', 'eog', 'hbo', 'hbr',
+        'ecog', 'seeg'].
+    cv : int | sklearn.model_selection object
+        Defaults to cv=5.
+    verbose : bool
         The verbosity of progress messages.
         If False, suppress all output messages.
 
@@ -213,7 +235,7 @@ def get_rejection_threshold(epochs, decim=1, random_state=None,
                          'or str. Got %s' % type(ch_types))
 
     if ch_types is None:
-        ch_types = ['mag', 'grad', 'eeg', 'eog', 'hbo', 'hbr']
+        ch_types = ['mag', 'grad', 'eeg', 'eog', 'hbo', 'hbr', 'ecog', 'seeg']
     elif isinstance(ch_types, str):
         ch_types = [ch_types]
 
@@ -237,6 +259,10 @@ def get_rejection_threshold(epochs, decim=1, random_state=None,
             picks = pick_types(epochs.info, meg='grad', eeg=False)
         elif ch_type in ['hbo', 'hbr']:
             picks = pick_types(epochs.info, meg=False, fnirs=ch_type)
+        elif ch_type == 'ecog':
+            picks = pick_types(epochs.info, ecog=True)
+        elif ch_type == 'seeg':
+            picks = pick_types(epochs.info, seeg=True)
 
         X = epochs.get_data()[:, picks, :]
         n_epochs, n_channels, n_times = X.shape
@@ -312,10 +338,11 @@ def _compute_thresh(this_data, method='bayesian_optimization',
         Data for one channel.
     method : str
         'bayesian_optimization' or 'random_search'
-    cv : iterator
+    cv : int | iterator
         Iterator for cross-validation.
-    random_state : int seed, RandomState instance, or None (default)
+    random_state : int | np.random.RandomState | None
         The seed of the pseudo random number generator to use.
+        Defaults to None.
 
     Returns
     -------
@@ -378,8 +405,9 @@ def compute_thresholds(epochs, method='bayesian_optimization',
         The epochs objects whose thresholds must be computed.
     method : str
         'bayesian_optimization' or 'random_search'
-    random_state : int seed, RandomState instance, or None (default)
-        The seed of the pseudo random number generator to use
+    random_state : int | np.random.RandomState | None
+        The seed of the pseudo random number generator to use.
+        Defaults to None.
     picks : str | list | slice | None
         Channels to include. Slices and lists of integers will be interpreted
         as channel indices. In lists, channel *type* strings (e.g.,
@@ -389,10 +417,10 @@ def compute_thresholds(epochs, method='bayesian_optimization',
         ``'data'`` to pick data channels. None (default) will pick data
         channels {'meg', 'eeg'}. Note that channels in ``info['bads']`` *will
         be included* if their names or indices are explicitly provided.
-    augment : boolean
+    augment : bool
         Whether to augment the data or not. By default it is True, but
         set it to False, if the channel locations are not available.
-    verbose : boolean
+    verbose : bool
         The verbosity of progress messages.
         If False, suppress all output messages.
     n_jobs : int
@@ -421,7 +449,7 @@ def _compute_thresholds(epochs, method='bayesian_optimization',
     if method not in ['bayesian_optimization', 'random_search']:
         raise ValueError('`method` param not recognized')
     picks = _handle_picks(info=epochs.info, picks=picks)
-    _check_data(epochs, picks, verbose=verbose,
+    _check_data(epochs, picks, verbose=verbose, check_loc=augment,
                 ch_constraint='data_channels')
     picks_by_type = _get_picks_by_type(picks=picks, info=epochs.info)
     picks_by_type = None if len(picks_by_type) == 1 else picks_by_type  # XXX
@@ -484,12 +512,12 @@ class _AutoReject(BaseAutoReject):
         'bayesian_optimization' or 'random_search'.
     dots : tuple
         2-length tuple returned by utils._compute_dots.
-    verbose : boolean
+    verbose : bool
         The verbosity of progress messages.
         If False, suppress all output messages.
 
     Attributes
-    -----------
+    ----------
     bad_segments : array, shape (n_epochs, n_channels)
         A boolean matrix where 1 denotes a bad data segment
         according to the sensor thresholds.
@@ -506,7 +534,7 @@ class _AutoReject(BaseAutoReject):
     """
 
     def __init__(self, n_interpolate=0, consensus=0.1, thresh_func=None,
-                 picks=None, thresh_method='bayesian_optimization',  dots=None,
+                 picks=None, thresh_method='bayesian_optimization', dots=None,
                  verbose=True):
         """Init it."""
         if thresh_func is None:
@@ -596,7 +624,7 @@ class _AutoReject(BaseAutoReject):
         bad_sensor_counts = np.sort(bad_sensor_counts)[::-1]
         n_channels = len(picks)
         n_consensus = self.consensus_[ch_type] * n_channels
-        bad_epochs = np.zeros(len(bad_sensor_counts), dtype=np.bool)
+        bad_epochs = np.zeros(len(bad_sensor_counts), dtype=bool)
         if np.max(bad_sensor_counts) >= n_consensus:
             n_epochs_drop = np.sum(bad_sensor_counts >=
                                    n_consensus)
@@ -718,7 +746,7 @@ class _AutoReject(BaseAutoReject):
             The cleaned epochs.
 
         reject_log : instance of autoreject.RejectLog
-            The rejection log. Returned only of return_log is True.
+            If not None, override the reject log determined by autoreject.
         """
         _check_data(epochs, picks=self.picks, verbose=self.verbose,
                     ch_constraint='data_channels')
@@ -832,49 +860,52 @@ def _run_local_reject_cv(epochs, thresh_func, picks_, n_interpolate, cv,
     return local_reject, loss
 
 
-class AutoReject(object):
+class AutoReject:
     r"""Efficiently find n_interpolate and consensus.
 
     .. note::
-       AutoReject by design supports multiple channels.
-       If no picks are passed, separate solutions will be computed for each
-       channel type and internally combined. This then readily supports
-       cleaning unseen epochs from the different channel types used during fit.
+        AutoReject by design supports multiple channels.
+        If no picks are passed, separate solutions will be computed for each
+        channel type and internally combined. This then readily supports
+        cleaning unseen epochs from the different channel types used during
+        fit.
 
     Parameters
     ----------
     n_interpolate : array | None
-        The values to try for the number of channels for which to interpolate.
-        This is :math:`\\rho`. If None, defaults to np.array([1, 4, 32])
+        The values to try for the number of channels for which to
+        interpolate. This is :math:`\\rho`. If None, defaults to
+        ``np.array([1, 4, 32])``
     consensus : array | None
         The values to try for percentage of channels that must agree as a
-        fraction of the total number of channels. This sets :math:`\\kappa/Q`.
-        If None, defaults to `np.linspace(0, 1.0, 11)`
-    cv : a scikit-learn cross-validation object
-        Defaults to cv=10
+        fraction of the total number of channels. This sets
+        :math:`\\kappa/Q`. If None, defaults to ``np.linspace(0, 1.0, 11)``
+    cv : int | sklearn.model_selection object
+        Defaults to cv=10.
     picks : str | list | slice | None
-        Channels to include. Slices and lists of integers will be interpreted
-        as channel indices. In lists, channel *type* strings (e.g.,
-        ``['meg', 'eeg']``) will pick channels of those types, channel *name*
-        strings (e.g., ``['MEG0111', 'MEG2623']`` will pick the given channels.
-        Can also be the string values ``'all'`` to pick all channels, or
-        ``'data'`` to pick data channels. None (default) will pick data
-        channels {'meg', 'eeg'}, which will lead fitting and combining
-        autoreject solutions across these channel types. Note that channels in
-        ``info['bads']`` *will be included* if their names or indices are
-        explicitly provided.
+        Channels to include. Slices and lists of integers will be
+        interpreted as channel indices. In lists, channel *type* strings
+        (e.g., ``['meg', 'eeg']``) will pick channels of those types,
+        channel *name* strings (e.g., ``['MEG0111', 'MEG2623']`` will pick
+        the given channels. Can also be the string values ``'all'`` to pick
+        all channels, or ``'data'`` to pick data channels. None (default)
+        will pick data channels {'meg', 'eeg'}, which will lead fitting and
+        combining  autoreject solutions across these channel types. Note
+        that channels in ``info['bads']`` *will be included* if their names
+        or indices are explicitly provided.
     thresh_method : str
         'bayesian_optimization' or 'random_search'
     n_jobs : int
         The number of jobs.
-    random_state : int seed, RandomState instance, or None (default)
+    random_state : int | np.random.RandomState | None
         The seed of the pseudo random number generator to use.
-    verbose : boolean
+        Defaults to None.
+    verbose : bool
         The verbosity of progress messages.
         If False, suppress all output messages.
 
     Attributes
-    -----------
+    ----------
     local_reject_ : list
         The instances of _AutoReject for each channel type.
     threshes_ : dict
@@ -895,7 +926,7 @@ class AutoReject(object):
                  thresh_func=None, cv=10, picks=None,
                  thresh_method='bayesian_optimization',
                  n_jobs=1, random_state=None, verbose=True):
-        """Init it."""
+        """Initialize the AutoReject class."""
         self.n_interpolate = n_interpolate
         self.consensus = consensus
         self.thresh_method = thresh_method
@@ -983,7 +1014,7 @@ class AutoReject(object):
             meg_picks = pick_types(epochs.info, meg=True,
                                    eeg=False, exclude=[])
             this_info = mne.pick_info(epochs.info, meg_picks, copy=True)
-            self.dots = _compute_dots(this_info)
+            self.dots = _compute_dots(this_info, templates=None)
 
         thresh_func = partial(_compute_thresholds, n_jobs=self.n_jobs,
                               method=self.thresh_method,
@@ -1069,7 +1100,7 @@ class AutoReject(object):
         labels.fill(np.nan)
         reject_log = RejectLog(
             labels=labels,
-            bad_epochs=np.zeros(len(epochs), dtype=np.bool),
+            bad_epochs=np.zeros(len(epochs), dtype=bool),
             ch_names=ch_names)
 
         picks_by_type = _get_picks_by_type(info=epochs.info, picks=self.picks_)
@@ -1083,7 +1114,7 @@ class AutoReject(object):
             reject_log.ch_names = this_reject_log.ch_names
         return reject_log
 
-    def transform(self, epochs, return_log=False):
+    def transform(self, epochs, return_log=False, reject_log=None):
         """Remove bad epochs, repairs sensors and returns clean epochs.
 
         Parameters
@@ -1094,6 +1125,10 @@ class AutoReject(object):
         return_log : bool
             If true the rejection log is also returned.
 
+        reject_log : instance of autoreject.RejectLog | None
+            The reject log to use. If None, the default reject log
+            is used.
+
         Returns
         -------
         epochs_clean : instance of mne.Epochs
@@ -1107,8 +1142,12 @@ class AutoReject(object):
             raise ValueError('Please run autoreject.fit() method first')
 
         _check_data(epochs, picks=self.picks_, verbose=self.verbose)
+        if reject_log is not None and not isinstance(reject_log, RejectLog):
+            raise ValueError('reject_log must be an instance of RejectLog, '
+                             f'got {type(reject_log)}')
 
-        reject_log = self.get_reject_log(epochs)
+        if reject_log is None:
+            reject_log = self.get_reject_log(epochs)
         epochs_clean = epochs.copy()
         _apply_interp(reject_log, epochs_clean, self.threshes_,
                       self.picks_, self.dots, self.verbose)
@@ -1212,7 +1251,7 @@ def _get_interp_chs(labels, ch_names, picks):
     return interp_channels
 
 
-class RejectLog(object):
+class RejectLog:
     """The Rejection Log.
 
     Parameters
@@ -1228,6 +1267,7 @@ class RejectLog(object):
     """
 
     def __init__(self, bad_epochs, labels, ch_names):
+        """Initialize the Rejection Log."""
         self.bad_epochs = bad_epochs
         self.labels = labels
         self.ch_names = ch_names
@@ -1240,7 +1280,7 @@ class RejectLog(object):
 
         Parameters
         ----------
-        orientation : 'vertical' or 'horizontal'
+        orientation : 'vertical' | 'horizontal'
             If `'vertical'` (default), will plot sensors on x-axis and epochs
             on y-axis. If `'horizontal'`, will plot epochs on x-axis and
             sensors on y-axis.
@@ -1256,7 +1296,7 @@ class RejectLog(object):
 
         Returns
         -------
-        figure : Instance of matplotlib.figure.Figure
+        figure : matplotlib.figure.Figure
             The figure object containing the plot.
         """
         import matplotlib as mpl
@@ -1337,7 +1377,7 @@ class RejectLog(object):
 
         Parameters
         ----------
-        epochs : instance of Epochs
+        epochs : instance of mne.Epochs
             The epochs.
         scalings : dict | None
             Scaling factors for the traces. If None, defaults to::
@@ -1350,7 +1390,7 @@ class RejectLog(object):
 
         Returns
         -------
-        fig : Instance of matplotlib.figure.Figure
+        fig : matplotlib.figure.Figure
             Epochs traces.
         """
         labels = self.labels
@@ -1385,10 +1425,28 @@ class RejectLog(object):
                 if not np.isnan(this_label):
                     epoch_color.append(color_map[this_label])
                 else:
-                    epoch_color.append(None)
+                    epoch_color.append('k')
             epoch_colors.append(epoch_color)
 
         return plot_mne_epochs(
             epochs=epochs,
             epoch_colors=epoch_colors, scalings=scalings,
-            title='')
+            title=title)
+
+    def save(self, fname, overwrite=False):
+        """Save a reject log.
+
+        Parameters
+        ----------
+        fname : str
+            The filename to save to. The filename must end in '.npz'.
+        overwrite : bool
+            If True, overwrite file if it already exists. Defaults to False.
+        """
+        fname = op.realpath(fname)
+        if not overwrite and op.isfile(fname):
+            raise ValueError(f'{fname} already exists. Please set '
+                             'overwrite=True if you want to overwrite it.')
+
+        np.savez_compressed(fname, ch_names=self.ch_names,
+                            bad_epochs=self.bad_epochs, labels=self.labels)
