@@ -5,7 +5,7 @@ from numpy.testing import assert_array_equal, assert_array_almost_equal
 import pytest
 
 import mne
-from mne.datasets import sample
+from mne.datasets import testing
 from mne.bem import _check_origin
 from mne import io
 
@@ -13,19 +13,19 @@ from autoreject.utils import clean_by_interp, interpolate_bads
 from autoreject.utils import _interpolate_bads_eeg
 import mne.channels.interpolation
 
-data_path = sample.data_path()
-raw_fname = data_path + '/MEG/sample/sample_audvis_filt-0-40_raw.fif'
-raw = io.read_raw_fif(raw_fname, preload=False)
-raw.crop(0, 15)
-raw.del_proj()
-
-evoked_fname = data_path + '/MEG/sample/sample_audvis-ave.fif'
-evoked = mne.read_evokeds(evoked_fname, condition='Left Auditory',
-                          baseline=(None, 0))
+data_path = testing.data_path(download=False)
+raw_fname = data_path / 'MEG' / 'sample' / 'sample_audvis_trunc_raw.fif'
+evoked_fname = data_path / 'MEG' / 'sample' / 'sample_audvis-ave.fif'
 
 
+@testing.requires_testing_data
 def test_utils():
     """Test utils."""
+    raw = io.read_raw_fif(raw_fname, preload=False)
+    raw.crop(0, 15)
+    raw.del_proj()
+    evoked = mne.read_evokeds(evoked_fname, condition='Left Auditory',
+                              baseline=(None, 0))
     event_id = {'Visual/Left': 3}
     tmin, tmax = -0.2, 0.5
     events = mne.find_events(raw)
@@ -68,18 +68,22 @@ def test_utils():
     assert_array_almost_equal(evoked_ar.data, evoked_mne.data)
 
 
+@testing.requires_testing_data
 def test_interpolate_bads():
     """Test interpolate bads."""
+    raw = io.read_raw_fif(raw_fname, preload=False)
+    raw.crop(0, 15)
+    raw.del_proj()
     event_id = None
     events = mne.find_events(raw)
     tmin, tmax = -0.2, 0.5
     for ii, ch_name in enumerate(raw.info['ch_names'][:14]):
-        raw.set_channel_types({ch_name: 'bio'})
+        raw.set_channel_types({ch_name: 'bio'}, verbose='error')
         raw.rename_channels({ch_name: 'BIO%02d' % ii})
 
     picks = mne.pick_types(raw.info, meg='grad', eeg=False, eog=False)
     epochs = mne.Epochs(raw, events, event_id, tmin, tmax,
                         baseline=(None, 0), decim=10,
-                        reject=None, preload=True)[:10]
+                        reject=None, preload=True, verbose='error')[:10]
     epochs.info['bads'] = ['MEG 2212']
     interpolate_bads(epochs, picks)
