@@ -28,7 +28,7 @@ def _check_ch_locs(chs):
                 np.allclose(locs3d, 0.))
 
 
-def _check_data(epochs, picks, ch_constraint='data_channels',
+def _check_data(epochs, picks, ch_constraint='data_channels', check_loc=True,
                 verbose=True):
     BaseEpochs = _get_epochs_type()
     if not isinstance(epochs, BaseEpochs):
@@ -43,21 +43,20 @@ def _check_data(epochs, picks, ch_constraint='data_channels',
         mne.io.meas_info.channel_type(picked_info, idx)
         for idx in range(len(picks))}
 
-    if not _check_ch_locs(picked_info['chs']):
+    if check_loc and not _check_ch_locs(picked_info['chs']):
         raise RuntimeError('Valid channel positions are needed '
                            'for autoreject to work')
 
     # XXX : ch_constraint -> allow_many_types=True | False
+    supported_channels = ['mag', 'grad', 'eeg', 'hbo', 'hbr', 'ecog', 'seeg']
+    channel_text = ', '.join(x for x in supported_channels)
+    message = f'AutoReject only supports {channel_text} currenly.'
     if ch_constraint == 'data_channels':
-        if not all(ch in ('mag', 'grad', 'eeg', 'hbo', 'hbr')
-                   for ch in ch_types_picked):
-            raise ValueError('AutoReject only supports mag, grad, and eeg '
-                             'at this point.')
+        if not all(ch in supported_channels for ch in ch_types_picked):
+            raise ValueError(message)
     elif ch_constraint == 'single_channel_type':
-        if sum(ch in ch_types_picked for ch in ('mag', 'grad', 'eeg',
-                                                'hbo', 'hbr')) > 1:
-            raise ValueError('AutoReject only supports mag, grad, and eeg '
-                             'at this point.')  # XXX: to check
+        if sum(ch in ch_types_picked for ch in supported_channels) > 1:
+            raise ValueError(message)  # XXX: to check
     else:
         raise ValueError('bad value for ch_constraint.')
 
@@ -73,7 +72,7 @@ def _handle_picks(info, picks):
     """Pick the data channls or return picks."""
     if picks is None:
         out = mne.pick_types(info, meg=True, eeg=True, ref_meg=False,
-                             fnirs=True, exclude='bads')
+                             fnirs=True, ecog=True, seeg=True, exclude='bads')
     else:
         out = _picks_to_idx(info, picks, exclude='bads')
     return out
@@ -166,14 +165,22 @@ def _pprint(params, offset=0, printer=repr):
 
 
 def _pbar(iterable, desc, verbose=True, **kwargs):
-    if (isinstance(verbose, str) and
-            verbose not in {"tqdm", "tqdm_notebook", "progressbar"}):
-        raise ValueError("verbose must be a boolean value. Got %s" % verbose)
-    elif isinstance(verbose, (int, str)):
+    raise_error = False
+    if isinstance(verbose, str):
+        if verbose not in {"tqdm", "tqdm_notebook", "progressbar"}:
+            raise_error = True
+        verbose = bool(verbose)
+    elif isinstance(verbose, (int, bool)):
+        verbose = bool(verbose)  # this can happen with pickling
+    else:
+        raise_error = True
         warnings.warn(
             (f"verbose flag only supports boolean inputs. Option {verbose} "
-                f"coerced into type {bool(verbose)}"), DeprecationWarning)
+             f"coerced into type {bool(verbose)}"), DeprecationWarning)
         verbose = bool(verbose)
+    if raise_error:
+        raise ValueError(
+            f"verbose must be a boolean value. Got {repr(verbose)}")
     if verbose:
         from mne.utils.progressbar import ProgressBar
         pbar = ProgressBar(iterable, mesg=desc, **kwargs)
@@ -195,7 +202,7 @@ def clean_by_interp(inst, picks=None, verbose=True):
 
     Parameters
     ----------
-    inst : instance of mne.Evoked or mne.Epochs
+    inst : mne.Evoked | mne.Epochs
         The evoked or epochs object.
     picks : str | list | slice | None
         Channels to include. Slices and lists of integers will be interpreted
@@ -206,7 +213,7 @@ def clean_by_interp(inst, picks=None, verbose=True):
         ``'data'`` to pick data channels. None (default) will pick data
         channels {'meg', 'eeg'}. Note that channels in ``info['bads']`` *will
         be included* if their names or indices are explicitly provided.
-    verbose : boolean
+    verbose : bool
         The verbosity of progress messages.
         If False, suppress all output messages.
 
@@ -248,31 +255,23 @@ def _clean_by_interp(inst, picks=None, dots=None, verbose=True):
 def interpolate_bads(inst, picks, dots=None, reset_bads=True, mode='accurate'):
     """Interpolate bad MEG and EEG channels."""
     import mne
-    # to prevent cobyla printf error
-    # XXX putting to critical for now unless better solution
-    # emerges
-    verbose = mne.set_log_level('CRITICAL', return_old_level=True)
-
     eeg_picks = set(pick_types(inst.info, meg=False, eeg=True, exclude=[]))
     eeg_picks_interp = [p for p in picks if p in eeg_picks]
-    if len(eeg_picks_interp) > 0:
-        _interpolate_bads_eeg(inst, picks=eeg_picks_interp)
-
     meg_picks = set(pick_types(inst.info, meg=True, eeg=False, exclude=[]))
     meg_picks_interp = [p for p in picks if p in meg_picks]
-    if len(meg_picks_interp) > 0:
-        _interpolate_bads_meg_fast(inst, picks=meg_picks_interp,
-                                   dots=dots, mode=mode)
-
+    # to prevent cobyla printf error
+    with mne.utils.use_log_level('error'):
+        if len(eeg_picks_interp) > 0:
+            _interpolate_bads_eeg(inst, picks=eeg_picks_interp)
+        if len(meg_picks_interp) > 0:
+            _interpolate_bads_meg_fast(inst, picks=meg_picks_interp,
+                                       dots=dots, mode=mode)
     if reset_bads is True:
         inst.info['bads'] = []
-
-    mne.set_log_level(verbose)
-
     return inst
 
 
-def _interpolate_bads_eeg(inst, picks=None, verbose=False):
+def _interpolate_bads_eeg(inst, picks=None):
     """ Interpolate bad EEG channels.
 
     Operates in place.
@@ -301,8 +300,8 @@ def _interpolate_bads_eeg(inst, picks=None, verbose=False):
     else:
         picks = _handle_picks(inst.info, picks)
 
-    bads_idx = np.zeros(len(inst.ch_names), dtype=np.bool)
-    goods_idx = np.zeros(len(inst.ch_names), dtype=np.bool)
+    bads_idx = np.zeros(len(inst.ch_names), dtype=bool)
+    goods_idx = np.zeros(len(inst.ch_names), dtype=bool)
     bads_idx[picks] = [inst.ch_names[ch] in inst.info['bads'] for ch in picks]
 
     if len(picks) == 0 or bads_idx.sum() == 0:
@@ -337,7 +336,7 @@ def _interpolate_bads_eeg(inst, picks=None, verbose=False):
 
 
 def _interpolate_bads_meg_fast(inst, picks, mode='accurate',
-                               dots=None, verbose=False):
+                               dots=None):
     """Interpolate bad channels from data in good channels."""
     # We can have pre-picked instances or not.
     # And we need to handle it.
@@ -392,13 +391,14 @@ def _interpolate_bads_meg_fast(inst, picks, mode='accurate',
     _do_interp_dots(inst, mapping, picks_good_, picks_bad_orig)
 
 
-def _compute_dots(info, mode='fast'):
+def _compute_dots(info, mode='fast', *, templates):
     """Compute all-to-all dots."""
     from mne.forward._lead_dots import _do_self_dots, _do_cross_dots
     from mne.forward._make_forward import _create_meg_coils, _read_coil_defs
     from mne.bem import _check_origin
 
-    templates = _read_coil_defs()
+    if templates is None:
+        templates = _read_coil_defs(verbose='error')
     coils = _create_meg_coils(info['chs'], 'normal', info['dev_head_t'],
                               templates)
     my_origin = _check_origin((0., 0., 0.04), info)
@@ -429,12 +429,8 @@ def _fast_map_meg_channels(info, pick_from, pick_to,
 
     miss = 1e-4  # Smoothing criterion for MEG
 
-    # XXX: hack to silence _compute_mapping_matrix
-    verbose = mne.get_config('MNE_LOGGING_LEVEL', 'INFO')
-    mne.set_log_level('WARNING')
-
     info_from = pick_info(info, pick_from, copy=True)
-    templates = _read_coil_defs()
+    templates = _read_coil_defs(verbose='error')
     coils_from = _create_meg_coils(info_from['chs'], 'normal',
                                    info_from['dev_head_t'], templates)
     my_origin = _check_origin((0., 0., 0.04), info_from)
@@ -444,7 +440,8 @@ def _fast_map_meg_channels(info, pick_from, pick_to,
     # This function needs a clean input. It hates the presence of other
     # channels than MEG channels. Make sure all is picked.
     if dots is None:
-        dots = self_dots, cross_dots = _compute_dots(info, mode=mode)
+        dots = self_dots, cross_dots = _compute_dots(
+            info, mode=mode, templates=templates)
     else:
         self_dots, cross_dots = dots
 
@@ -455,8 +452,9 @@ def _fast_map_meg_channels(info, pick_from, pick_to,
                origin=my_origin, noise=noise, self_dots=self_dots,
                surface_dots=cross_dots, int_rad=int_rad, miss=miss)
 
-    fmd['data'] = _compute_mapping_matrix(fmd, info_from)
-    mne.set_log_level(verbose)
+    # XXX: hack to silence _compute_mapping_matrix
+    with mne.utils.use_log_level('error'):
+        fmd['data'] = _compute_mapping_matrix(fmd, info_from)
 
     return fmd['data']
 
@@ -469,3 +467,29 @@ def _patch_setup_dots(mode, info, coils, ch):
         return _setup_dots(mode, coils, ch)
     else:
         return _setup_dots(mode, info, coils, ch)
+
+
+def _get_channel_type(epochs, picks):
+    """return whether a set of picks are all meg or all eeg channels."""
+    picked_info = mne.io.pick.pick_info(epochs.info, picks)
+    ch_types_picked = {
+        mne.io.meas_info.channel_type(picked_info, idx)
+        for idx in range(len(picks))}
+    invalid_ch_types_present = [key for key in ch_types_picked
+                                if key not in ['mag', 'grad', 'eeg'] and
+                                key in epochs]
+    if len(invalid_ch_types_present) > 0:
+        raise ValueError('Invalid channel types present in epochs.'
+                         ' Expected ONLY `meg` or ONLY `eeg`. Got %s'
+                         % ', '.join(invalid_ch_types_present))
+
+    has_meg = any(kk in ch_types_picked for kk in ('mag', 'grad'))
+    if 'eeg' in ch_types_picked and has_meg:
+        raise ValueError('Got mixed channel types. Pick either eeg or meg'
+                         ' but not both')
+    if 'eeg' in ch_types_picked:
+        return 'eeg'
+    elif has_meg:
+        return 'meg'
+    else:
+        raise ValueError('Oh no! Your channel type is not known.')
