@@ -18,14 +18,14 @@ from mne import io
 from mne.datasets import sample
 
 data_path = sample.data_path()
-raw_fname = data_path + '/MEG/sample/sample_audvis_filt-0-40_raw.fif'
+meg_path = data_path / 'MEG' / 'sample'
+raw_fname = meg_path / 'sample_audvis_filt-0-40_raw.fif'
 raw = io.read_raw_fif(raw_fname, preload=True)
 
 ###############################################################################
 # We can extract the events (or triggers) for epoching our signal.
 
-event_fname = data_path + ('/MEG/sample/sample_audvis_filt-0-40_raw-'
-                           'eve.fif')
+event_fname = meg_path / 'sample_audvis_filt-0-40_raw-eve.fif'
 event_id = {'Auditory/Left': 1}
 tmin, tmax = -0.2, 0.5
 events = mne.read_events(event_fname)
