@@ -22,9 +22,9 @@ event_id = {'Visual/Left': 3}
 tmin, tmax = -0.2, 0.5
 
 data_path = sample.data_path()
-raw_fname = data_path + '/MEG/sample/sample_audvis_filt-0-40_raw.fif'
-event_fname = data_path + ('/MEG/sample/sample_audvis_filt-0-40_raw-'
-                           'eve.fif')
+meg_path = data_path / 'MEG' / 'sample'
+raw_fname = meg_path / 'sample_audvis_filt-0-40_raw.fif'
+event_fname = meg_path / 'sample_audvis_filt-0-40_raw-eve.fif'
 
 raw = io.read_raw_fif(raw_fname, preload=True)
 events = mne.read_events(event_fname)
@@ -46,7 +46,7 @@ param_range = np.linspace(40e-6, 200e-6, 30)
 ###############################################################################
 # Next, we can use :func:`autoreject.validation_curve` to compute the Root Mean
 # Squared (RMSE) values at the candidate thresholds. Under the hood, this is
-# using  :class:`autoreject._GlobalAutoReject` to find global (i.e., for all
+# using  ``autoreject._GlobalAutoReject`` to find global (i.e., for all
 # channels) peak-to-peak thresholds.
 
 from autoreject import validation_curve  # noqa
